pilas.actores.ejes

Package pilas :: Package actores :: Module ejes |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.ejes

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  from pilas.actores import Actor
    10
    11 -class Ejes(Actor):
    12      """Representa el eje de coordenadas tomado como sistema de referencia.
    13
    14      Este actor es útil para mostrar que la ventana
    15      de pilas tiene una referencia, y que las posiciones
    16      responden a este modelo.
    17
    18      Para crear el eje podrías ejecutar:
    19
    20          >>> eje = pilas.actore.Eje()
    21
    22      """
    23
    24 -    def __init__(self, x=0, y=0):
    25          """ Constructor de los ejes.
    26
    27          :param x: Posición horizontal de los ejes.
    28          :type x: int
    29          :param y: Posición vertical de los ejes.
    30          :type y: int
    31          """
    32          Actor.__init__(self, "ejes.png", x=x, y=y)
    33          self.z = 100
    34